Package: kstIO
Version: 0.5-1
Date: 2026-04-11
Title: Knowledge Space Theory Input/Output
Authors@R: c(person(given = "Cord", family = "Hockemeyer", 
                    role = c("aut", "cre"),
	            email = "cord.hockemeyer@uni-graz.at"))
Description: Knowledge space theory by Doignon and Falmagne (1999) 
   <doi:10.1007/978-3-642-58625-5> is a set- and order-theoretical
   framework which proposes mathematical formalisms to operationalize 
   knowledge structures in a particular domain.  The 'kstIO' package 
   provides basic functionalities to read and write KST data from/to 
   files to be used together with the 'kst', 'kstMatrix', 'pks', or 
   'DAKS' packages.
License: GPL (>= 3)
Depends: R (>= 4.4.0), sets, kstMatrix (>= 2.3-0), openxlsx2, readODS,
        tools
Author: Cord Hockemeyer [aut, cre]
Maintainer: Cord Hockemeyer <cord.hockemeyer@uni-graz.at>
NeedsCompilation: no
Repository: CRAN
Encoding: UTF-8
Packaged: 2026-04-11 11:56:51 UTC; hockemey
Date/Publication: 2026-04-11 12:30:02 UTC
Built: R 4.5.2; ; 2026-04-11 14:13:45 UTC; unix
