import("kstMatrix")
import("sets")
importFrom("utils", "read.csv", "read.csv2", "write.table")
importFrom("openxlsx2", "read_xlsx", "write_xlsx")
importFrom("tools", "file_ext")
importFrom("readODS", "read_ods", "write_ods")

export("read_kbase",
       "read_kdata",
       "read_kfamset",
       "read_kspace",
       "read_kstructure",
       "read_surmisefunction",
       "read_surmiserelation",
       "write_kbase",
       "write_kdata",
       "write_kfamset",
       "write_kspace",
       "write_kstructure",
       "write_surmisefunction",
       "write_surmiserelation"
)

