\encoding{UTF-8}
\name{write_surmisefunction}
\alias{write_surmisefunction}
\title{Write a surmise function file}

\description{
  Write a surmise function to
  a file. The file formats are described in the \link{kstIO-package}
  information page.
}

\usage{
  write_surmisefunction(x, filename, sep=',')
}

\arguments{
  \item{x}{The data to be written, either a quadratic binary matrix or an object
    of \code{relation} class.}
  \item{filename}{A character string specifying the name of the base file.}
  \item{sep}{Cell separator for CSAV files.}
}

\details{
  Surmise function can (so far) be stored only in spreadsheet formats. The concrete
  file type (CSV, ODS, or XLSX) is determined from the filename extension.
}

\author{Cord Hockemeyer \email{cord.hockemeyer@uni-graz.at}}

\seealso{\link{kstIO-package}}


\keyword{file}
