\encoding{UTF-8}
\name{read_surmisefunction}
\alias{read_surmisefunction}
\title{Read surmise function file}

\description{
  Read a surmise function from
  a file. The file formats are described in the \link{kstIO-package}
  information page.
}

\usage{
  read_surmisefunction(filename)
}

\arguments{
  \item{filename}{A character string specifying the name of the surmise function file.}
}

\details{
  Surmise function files exist (so far) only in spreadsheet format. The concrete
  file type is derived from the filname extension.
}

\value{A data frame containing the surmise function.}

\author{Cord Hockemeyer \email{cord.hockemeyer@uni-graz.at}}

\seealso{\link{kstIO-package}}

\examples{
d <- getwd()
setwd(tempdir())
sf <- kmsurmisefunction(phsg$basis)
write_surmisefunction(sf, "phsg_sf.xlsx")
read_surmisefunction("phsg_sf.xlsx")
setwd(d)
}
 
\keyword{file}
